@@ -85,7 +85,6 @@ class CompressedLogger(Handler):
         """
         live_logs = [str(x) for x in self.base_path.glob(f"{self.filename}*.log")]
         live_logs.sort(key=lambda x: os.path.getctime(x), reverse=True)
-
         if len(live_logs) > self.max_live_logs:
             old_log = live_logs.pop()
             archive_file = self._get_archive_for_log(old_log)
@@ -93,14 +92,20 @@ class CompressedLogger(Handler):
             if not os.path.exists(archive_file) and len(self.header) > 0:
                 include_header = True
 
-            with open(old_log, "rb") as f_in:
-                with gzip.open(archive_file, "ab") as f_out:
-                    if include_header:
-                        f_out.write((self.header + "\n").encode())
-                    f_out.write(f_in.read())
+            with gzip.open(archive_file, "ab") as f_out:
+                if include_header:
+                    f_out.write((self.header + "\n").encode())
 
+                with open(old_log, "rb") as f_in:
+                    while True:
+                        data = f_in.read(1024)
+                        if not data:
+                            break
+                        f_out.write(data)
             os.remove(old_log)
 
+
+
     def _get_archive_for_log(self, log_file: str):
         """
         :param log_file: path of the log file that shall be archived
